@@ -79,35 +79,13 @@ impl From<serde_json::Error> for Error {
 }
 
 impl error::Error for Error {
-    fn description(&self) -> &str {
-        use crate::Error::*;
-        match *self {
-            Io(ref err) => err.description(),
-            Utf8(ref err) => err.description(),
-            BadJson(ref err) => err.description(),
-            #[cfg(feature = "ram_bundle")]
-            Scroll(ref err) => err.description(),
-            VlqLeftover => "vlq leftover",
-            VlqNoValues => "no vlq values",
-            VlqOverflow => "overflow in vlq",
-            BadSegmentSize(_) => "bad segment size",
-            BadSourceReference(_) => "bad source reference",
-            BadNameReference(_) => "bad name reference",
-            IncompatibleSourceMap => "incompatible sourcemap",
-            InvalidDataUrl => "invalid data URL",
-            CannotFlatten(_) => "cannot flatten the given indexed sourcemap",
-            InvalidRamBundleMagic => "invalid magic number for ram bundle",
-            InvalidRamBundleIndex => "invalid module index in ram bundle",
-            InvalidRamBundleEntry => "invalid ram bundle module entry",
-            NotARamBundle => "not a ram bundle",
-        }
-    }
-
     fn cause(&self) -> Option<&dyn error::Error> {
-        use crate::Error::*;
         match *self {
-            Io(ref err) => Some(&*err),
-            Utf8(ref err) => Some(&*err),
+            Error::Io(ref err) => Some(err),
+            #[cfg(feature = "ram_bundle")]
+            Error::Scroll(ref err) => Some(err),
+            Error::Utf8(ref err) => Some(err),
+            Error::BadJson(ref err) => Some(err),
             _ => None,
         }
     }
@@ -115,26 +93,27 @@ impl error::Error for Error {
 
 impl fmt::Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        use crate::Error::*;
         match *self {
-            Io(ref msg) => write!(f, "{}", msg),
-            Utf8(ref msg) => write!(f, "{}", msg),
-            BadJson(ref err) => write!(f, "bad json: {}", err),
+            Error::Io(ref msg) => write!(f, "{}", msg),
+            Error::Utf8(ref msg) => write!(f, "{}", msg),
+            Error::BadJson(ref err) => write!(f, "bad json: {}", err),
             #[cfg(feature = "ram_bundle")]
-            Scroll(ref err) => write!(f, "parse error: {}", err),
-            VlqLeftover => write!(f, "leftover cur/shift in vlq decode"),
-            VlqNoValues => write!(f, "vlq decode did not produce any values"),
-            VlqOverflow => write!(f, "vlq decode caused an overflow"),
-            BadSegmentSize(size) => write!(f, "got {} segments, expected 4 or 5", size),
-            BadSourceReference(id) => write!(f, "bad reference to source #{}", id),
-            BadNameReference(id) => write!(f, "bad reference to name #{}", id),
-            IncompatibleSourceMap => write!(f, "encountered incompatible sourcemap format"),
-            InvalidDataUrl => write!(f, "the provided data URL is invalid"),
-            CannotFlatten(ref msg) => write!(f, "cannot flatten the indexed sourcemap: {}", msg),
-            InvalidRamBundleMagic => write!(f, "invalid magic number for ram bundle"),
-            InvalidRamBundleIndex => write!(f, "invalid module index in ram bundle"),
-            InvalidRamBundleEntry => write!(f, "invalid ram bundle module entry"),
-            NotARamBundle => write!(f, "not a ram bundle"),
+            Error::Scroll(ref err) => write!(f, "parse error: {}", err),
+            Error::VlqLeftover => write!(f, "leftover cur/shift in vlq decode"),
+            Error::VlqNoValues => write!(f, "vlq decode did not produce any values"),
+            Error::VlqOverflow => write!(f, "vlq decode caused an overflow"),
+            Error::BadSegmentSize(size) => write!(f, "got {} segments, expected 4 or 5", size),
+            Error::BadSourceReference(id) => write!(f, "bad reference to source #{}", id),
+            Error::BadNameReference(id) => write!(f, "bad reference to name #{}", id),
+            Error::IncompatibleSourceMap => write!(f, "encountered incompatible sourcemap format"),
+            Error::InvalidDataUrl => write!(f, "the provided data URL is invalid"),
+            Error::CannotFlatten(ref msg) => {
+                write!(f, "cannot flatten the indexed sourcemap: {}", msg)
+            }
+            Error::InvalidRamBundleMagic => write!(f, "invalid magic number for ram bundle"),
+            Error::InvalidRamBundleIndex => write!(f, "invalid module index in ram bundle"),
+            Error::InvalidRamBundleEntry => write!(f, "invalid ram bundle module entry"),
+            Error::NotARamBundle => write!(f, "not a ram bundle"),
         }
     }
 }
